{% extends "silk/base/base.html" %}
{% load nav %}
{% load inclusion %}
{% load staticfiles %}


{% block style %}
    <link rel="stylesheet" href="{% static 'silk/css/cell.css' %}"/>
    <link rel="stylesheet" href="{% static 'silk/css/numeric.css' %}"/>
    <style>
        .cell:hover {
            background-color: rgb(51, 51, 68);
            color: white;
            cursor: pointer;

        }

        .cell {
            text-align: center;
        }
    </style>
{% endblock %}

{% block js %}
    <script src="{% static 'silk/js/cell.js' %}"></script>
{% endblock %}

